@@ -3,14 +3,18 @@
  *
  * All rights reserved.
  *
- * This file is part of ObjFW. It may be distributed under the terms of the
- * Q Public License 1.0, which can be found in the file LICENSE.QPL included in
- * the packaging of this file.
+ * This program is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License version 3.0 only,
+ * as published by the Free Software Foundation.
  *
- * Alternatively, it may be distributed under the terms of the GNU General
- * Public License, either version 2 or 3, which can be found in the file
- * LICENSE.GPLv2 or LICENSE.GPLv3 respectively included in the packaging of this
- * file.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
+ * version 3.0 for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * version 3.0 along with this program. If not, see
+ * <https://www.gnu.org/licenses/>.
  */
 
 #import "OFObject.h"
@@ -23,7 +27,7 @@ OF_ASSUME_NONNULL_BEGIN
 OF_SUBCLASSING_RESTRICTED
 @interface OFMatrix4x4: OFObject <OFCopying>
 {
-	float _values[4][4];
+	OF_ALIGN(16) float _values[4][4];
 }
 
 #ifdef OF_HAVE_CLASS_PROPERTIES
@@ -90,6 +94,19 @@ OF_SUBCLASSING_RESTRICTED
  * @return The transformed vector
  */
 - (OFVector4D)transformedVector: (OFVector4D)vector;
+
+/**
+ * @brief Transforms the specified vectors in-place according to the matrix.
+ *
+ * @warning Please note that the vectors must be 16 byte aligned! This is
+ *	    required to allow SIMD optimizations. Passing a pointer to vectors
+ *	    that are not 16 byte aligned will crash if SIMD optimizations are
+ *	    enabled.
+ *
+ * @param vectors The vectors to transform
+ * @param count The count of the specified vectors
+ */
+- (void)transformVectors: (OFVector4D *)vectors count: (size_t)count;
 @end
 
 OF_ASSUME_NONNULL_END
